==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/icelandic_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Icelandic_Firefox
</name>

<description>
   <am>Icelandic localisation of Firefox</am>
   <ar>Icelandic localisation of Firefox</ar>
   <bg>Icelandic localisation of Firefox</bg>
   <ca>Localització de Firefox en Islandès</ca>
   <cs>Icelandic localisation of Firefox</cs>
   <da>Islandsk oversættelse af Firefox</da>
   <de>Isländische Lokalisierung von Firefox</de>
   <el>Ισλανδικός εντοπισμός του Firefox</el>
   <en>Icelandic localisation of Firefox</en>
   <es>Localización Islandesa de Firefox</es>
   <et>Icelandic localisation of Firefox</et>
   <eu>Icelandic localisation of Firefox</eu>
   <fa>Icelandic localisation of Firefox</fa>
   <fi>Icelandic localisation of Firefox</fi>
   <fr>Localisation islandaise pour Firefox</fr>
   <he_IL>Icelandic localisation of Firefox</he_IL>
   <hi>Icelandic localisation of Firefox</hi>
   <hr>Icelandic localisation of Firefox</hr>
   <hu>Icelandic localisation of Firefox</hu>
   <id>Icelandic localisation of Firefox</id>
   <is>Icelandic localisation of Firefox</is>
   <it>Localizzazione islandese di Firefox</it>
   <ja_JP>Icelandic localisation of Firefox</ja_JP>
   <ja>Icelandic localisation of Firefox</ja>
   <kk>Icelandic localisation of Firefox</kk>
   <ko>Icelandic localisation of Firefox</ko>
   <lt>Icelandic localisation of Firefox</lt>
   <mk>Icelandic localisation of Firefox</mk>
   <nb>Icelandic localisation of Firefox</nb>
   <nl>IJslandse lokalisatie van Firefox</nl>
   <pl>Islandzka lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Islandês Localização para Firefox</pt_BR>
   <pt>Islandês Localização para Firefox</pt>
   <ro>Icelandic localisation of Firefox</ro>
   <ru>Исландская локализация Firefox</ru>
   <sk>Icelandic localisation of Firefox</sk>
   <sl>Icelandic localisation of Firefox</sl>
   <sq>Icelandic localisation of Firefox</sq>
   <sr>Icelandic localisation of Firefox</sr>
   <sv>Isländsk lokalisering av Firefox </sv>
   <tr>Icelandic localisation of Firefox</tr>
   <uk>Icelandic локалізація Firefox</uk>
   <zh_CN>Icelandic localisation of Firefox</zh_CN>
   <zh_TW>Icelandic localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-is
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-is
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_20.05.01.tar.xz: mx-packageinstaller-pkglist/icelandic_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Icelandic_Firefox
</name>

<description>
   <am>Icelandic localisation of Firefox</am>
   <ar>Icelandic localisation of Firefox</ar>
   <bg>Icelandic localisation of Firefox</bg>
   <bn>Icelandic localisation of Firefox</bn>
   <ca>Localització de Firefox en Islandès</ca>
   <cs>Icelandic localisation of Firefox</cs>
   <da>Islandsk oversættelse af Firefox</da>
   <de>Isländische Lokalisierung von Firefox</de>
   <el>Ισλανδικός εντοπισμός του Firefox</el>
   <en>Icelandic localisation of Firefox</en>
   <es>Localización Islandesa de Firefox</es>
   <et>Icelandic localisation of Firefox</et>
   <eu>Icelandic localisation of Firefox</eu>
   <fa>Icelandic localisation of Firefox</fa>
   <fil_PH>Icelandic localisation of Firefox</fil_PH>
   <fi>Icelandic localisation of Firefox</fi>
   <fr>Localisation islandaise pour Firefox</fr>
   <he_IL>Icelandic localisation of Firefox</he_IL>
   <hi>Icelandic localisation of Firefox</hi>
   <hr>Icelandic localisation of Firefox</hr>
   <hu>Icelandic localisation of Firefox</hu>
   <id>Icelandic localisation of Firefox</id>
   <is>Icelandic localisation of Firefox</is>
   <it>Localizzazione islandese di Firefox</it>
   <ja_JP>Icelandic localisation of Firefox</ja_JP>
   <ja>Icelandic localisation of Firefox</ja>
   <kk>Icelandic localisation of Firefox</kk>
   <ko>Icelandic localisation of Firefox</ko>
   <lt>Icelandic localisation of Firefox</lt>
   <mk>Icelandic localisation of Firefox</mk>
   <mr>Icelandic localisation of Firefox</mr>
   <nb>Icelandic localisation of Firefox</nb>
   <nl>IJslandse lokalisatie van Firefox</nl>
   <pl>Islandzka lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Islandês Localização para Firefox</pt_BR>
   <pt>Islandês Localização para Firefox</pt>
   <ro>Icelandic localisation of Firefox</ro>
   <ru>Исландская локализация Firefox</ru>
   <sk>Icelandic localisation of Firefox</sk>
   <sl>Icelandic localisation of Firefox</sl>
   <sq>Icelandic localisation of Firefox</sq>
   <sr>Icelandic localisation of Firefox</sr>
   <sv>Isländsk lokalisering av Firefox </sv>
   <tr>Firefox'un İzlandaca yerelleştirmesi</tr>
   <uk>Icelandic локалізація Firefox</uk>
   <vi>Icelandic localisation of Firefox</vi>
   <zh_CN>Icelandic localisation of Firefox</zh_CN>
   <zh_TW>Icelandic localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-is
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-is
</uninstall_package_names>
</app>
